Create chat
^^^^^^^^^^^

Workflow has those steps:

#. add to database new chat instance
#. generate "invitation code"
#. registry system message for "chat creator" with "invitation code"
#. generate "user token"
